CVS: plexus-components/formica/src/java/org/codehaus/plexus/formica DefaultFormElement.java,1.1.1.1,1.2 FormElement.java,1.1.1.1,1.2 FormElementFactory.java,1.1.1.1,1.2

[email protected] Sun, 1 Jun 2003 15:55:02 -0500
Newsgroups gmane.comp.java.plexus.devel
Message-ID <[email protected]>
Update of /cvsroot/plexus/plexus-components/formica/src/java/org/codehaus/plexus/formica
In directory eng.werken.com:/tmp/cvs-serv8457/src/java/org/codehaus/plexus/formica

Modified Files:
	DefaultFormElement.java FormElement.java 
	FormElementFactory.java 
Log Message:
o Switching over to using messageKey and labelKey so that I can use a message
  store of some sort to take into account localization.


Index: FormElement.java
===================================================================
RCS file: /cvsroot/plexus/plexus-components/formica/src/java/org/codehaus/plexus/formica/FormElement.java,v
retrieving revision 1.1.1.1
retrieving revision 1.2
diff -u -d -r1.1.1.1 -r1.2
--- FormElement.java	1 Jun 2003 19:12:18 -0000	1.1.1.1
+++ FormElement.java	1 Jun 2003 20:55:00 -0000	1.2
@@ -64,8 +64,8 @@
     void setId( String id );
     String getId();
 
-    void setLabel( String label );
-    String getLabel();
+    void setLabelKey( String label );
+    String getLabelKey();
 
     String getDefaultValue();
     void setDefaultValue( String defaultValue );
@@ -73,8 +73,8 @@
     boolean isOptional();
     void setOptional( boolean optional );
 
-    void setMessage( String message );
-    String getMessage();
+    void setMessageKey( String message );
+    String getMessageKey();
 
     void setPropertyExpression( String propertyExpression );
     String getPropertyExpression();

Index: FormElementFactory.java
===================================================================
RCS file: /cvsroot/plexus/plexus-components/formica/src/java/org/codehaus/plexus/formica/FormElementFactory.java,v
retrieving revision 1.1.1.1
retrieving revision 1.2
diff -u -d -r1.1.1.1 -r1.2
--- FormElementFactory.java	1 Jun 2003 19:12:18 -0000	1.1.1.1
+++ FormElementFactory.java	1 Jun 2003 20:55:00 -0000	1.2
@@ -68,8 +68,8 @@
 
         String id = configuration.getAttribute( "id" );
         fe.setId( id );
-        fe.setLabel( configuration.getChild( "label" ).getValue( null ) );
-        fe.setMessage( configuration.getChild( "message" ).getValue( null ) );
+        fe.setLabelKey( configuration.getChild( "labelKey" ).getValue( null ) );
+        fe.setMessageKey( configuration.getChild( "messageKey" ).getValue( null ) );
         fe.setDefaultValue( configuration.getChild( "default" ).getValue( null ) );
         fe.setOptional( configuration.getAttributeAsBoolean( "optional", false ) );
         fe.setPropertyExpression( configuration.getChild( "property-expression" ).getValue( null ) );
Index: DefaultFormElement.java
===================================================================
RCS file: /cvsroot/plexus/plexus-components/formica/src/java/org/codehaus/plexus/formica/DefaultFormElement.java,v
retrieving revision 1.1.1.1
retrieving revision 1.2
diff -u -d -r1.1.1.1 -r1.2
--- DefaultFormElement.java	1 Jun 2003 19:12:17 -0000	1.1.1.1
+++ DefaultFormElement.java	1 Jun 2003 20:55:00 -0000	1.2
@@ -60,8 +60,8 @@
     implements FormElement
 {
     protected String id;
-    protected String label;
-    protected String message;
+    protected String labelKey;
+    protected String messageKey;
     protected String defaultValue;
     protected boolean optional;
     protected String propertyExpression;
@@ -100,14 +100,14 @@
         this.id = name;
     }
 
-    public String getLabel()
+    public String getLabelKey()
     {
-        return label;
+        return labelKey;
     }
 
-    public void setLabel( String label )
+    public void setLabelKey( String labelKey )
     {
-        this.label = label;
+        this.labelKey = labelKey;
     }
 
     /** Get the default value which is used if no data is submitted for the
@@ -165,17 +165,17 @@
         setOptional( "true".equalsIgnoreCase( optional ) );
     }
 
-    public void setMessage( String message )
+    public void setMessageKey( String messageKey )
     {
-        this.message = message;
+        this.messageKey = messageKey;
     }
 
-    /** Get the field's message in the default Locale.
-     @return The message
+    /** Get the field's messageKey in the default Locale.
+     @return The messageKey
      */
-    public String getMessage()
+    public String getMessageKey()
     {
-        return message;
+        return messageKey;
     }
 
     public void setPropertyExpression( String propertyExpression )
